@@ -222,10 +222,10 @@ compute_locale_variants (const gchar *locale)
 {
   GList *retval = NULL;
 
-  gchar *language;
-  gchar *territory;
-  gchar *codeset;
-  gchar *modifier;
+  gchar *language = NULL;
+  gchar *territory = NULL;
+  gchar *codeset = NULL;
+  gchar *modifier = NULL;
 
   guint mask;
   guint i;
